@@ -13,4 +13,4 @@ def run(args):
         cmdargs.append('--exit-with-status')
     cmdargs.extend(sys.argv[1:])
 
-    return subprocess.call(cmdargs)
+    return sys.exit(subprocess.call(cmdargs))
